# -*- coding: utf-8 -*-
# Generated by Django 1.11.28 on 2020-02-26 15:03
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0005_auto_20200210_1644'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='societe',
            options={},
        ),
    ]
