# -*- coding: utf-8 -*-
# Generated by Django 1.11.28 on 2020-02-28 16:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0007_societe_logo2'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='societe',
            name='logo2',
        ),
        migrations.AlterField(
            model_name='societe',
            name='logo',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Logo'),
        ),
    ]
