# Generated by Django 2.2.19 on 2021-05-11 15:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0012_auto_20210511_1652'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='activity',
            options={},
        ),
        migrations.AlterField(
            model_name='activity',
            name='name',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Forme alternative d’activité'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='name',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Nom de la société'),
        ),
    ]
