# -*- coding: utf-8 -*-
# Generated by Django 1.11.28 on 2020-03-05 10:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0008_auto_20200228_1709'),
    ]

    operations = [
        migrations.AlterField(
            model_name='societe',
            name='lat',
            field=models.DecimalField(blank=True, decimal_places=12, max_digits=15, null=True, verbose_name='Lattitude'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='lng',
            field=models.DecimalField(blank=True, decimal_places=12, max_digits=15, null=True, verbose_name='Longitude'),
        ),
    ]
