# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-02-10 15:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0004_auto_20200210_1440'),
    ]

    operations = [
        migrations.RenameField(
            model_name='societe',
            old_name='adress',
            new_name='address',
        ),
    ]
