# Generated by Django 2.2.19 on 2021-05-11 15:26

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0013_auto_20210511_1716'),
    ]

    operations = [
        migrations.AlterField(
            model_name='societe',
            name='activity',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='company_activity', to='faabrickmap_data.Activity', verbose_name='Forme alternative d’activité'),
        ),
    ]
