# Generated by Django 2.2.19 on 2021-05-11 18:35

from django.db import migrations


class Migration(migrations.Migration):
    atomic = False

    dependencies = [
        ('faabrickmap_data', '0014_auto_20210511_1726'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Activity',
            new_name='CompanyType',
        ),
    ]
