# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-01-30 20:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Activity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('name', models.CharField(max_length=250, verbose_name='Forme alternative d’activité')),
            ],
            options={
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'control'),
            },
        ),
        migrations.AddField(
            model_name='societe',
            name='adress',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Adresse'),
        ),
        migrations.AddField(
            model_name='societe',
            name='city',
            field=models.CharField(blank=True, max_length=15, null=True, verbose_name='Ville'),
        ),
        migrations.AddField(
            model_name='societe',
            name='lat',
            field=models.CharField(blank=True, max_length=25, null=True, verbose_name='Lattitude'),
        ),
        migrations.AddField(
            model_name='societe',
            name='lng',
            field=models.CharField(blank=True, max_length=25, null=True, verbose_name='Longitude'),
        ),
        migrations.AddField(
            model_name='societe',
            name='postcode',
            field=models.CharField(blank=True, max_length=5, null=True, verbose_name='Code Postal'),
        ),
        migrations.AddField(
            model_name='societe',
            name='siren',
            field=models.CharField(blank=True, max_length=15, null=True, verbose_name='Numéro de SIREN'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='logo',
            field=models.ImageField(blank=True, null=True, upload_to='', verbose_name='Logo'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Nom de la société'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='website',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Site web'),
        ),
        migrations.AddField(
            model_name='societe',
            name='activity',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='faabrickmap_data.Activity', verbose_name='Forme alternative d’activité'),
        ),
    ]
