# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-02-10 09:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0002_auto_20200130_2128'),
    ]

    operations = [
        migrations.AddField(
            model_name='societe',
            name='mail',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Adresse mail'),
        ),
        migrations.AddField(
            model_name='societe',
            name='peps',
            field=models.BooleanField(default='False', verbose_name='PEPS'),
        ),
        migrations.AddField(
            model_name='societe',
            name='phone',
            field=models.CharField(blank=True, max_length=12, null=True, verbose_name='Numéro de téléphone'),
        ),
    ]
